<?PHP

/*
Sphere - Distance to Horizon

Language: PHP v7.1.8
Author: Jay Tanner - 2018
www.NeoProgrammics.com

This program computes both the straight line-of-sight distance to the
sea-level horizon and the curved surface or sailing distance to that
horizon point.

----------------------------------------------------------------------------
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
----------------------------------------------------------------------------

*/
   $cYear = date("Y");

   $_ACTION_FILE_NAME_ = $_SERVER['SCRIPT_NAME'];

   $_PROGRAM_VERSION_ = "v2.0";


// Initialize error detection flag state
   $errorFlag = FALSE;

// Read radius and distance argument values
// from input interface.
   $R = trim(@$_POST['R']);
   $D = trim(@$_POST['D']);

// Set initial radius and distance default values in miles.
   if ($R == "" && $D == "") {$R = 1079.35;   $D = 2389;}

// Read selected radio button value
   $radioButtonIndex = trim(@$_POST['DistOption']);

// Set default selected radio button to
// distance measured from center.
   if ($radioButtonIndex == ""){$radioButtonIndex = 0;}

// Set number of radio buttons.
// In this case 2 buttons.
   $n = 2;

// Create radio button states array
   for ($i=0;   $i < $n;   $i++)
       {
        if ($i == $radioButtonIndex)
           {$radioButton[$i] = "CHECKED";} else {$radioButton[$i] = "";}
       }

// Error if either argument is non-numeric
   if (!is_numeric($R) || !is_numeric($D))
      {
       $errorFlag = TRUE;
       $out = "<B style='color:red;'>ERROR: Both arguments should be positive numeric values.</B>\n";
       $H = $S = "";
      }

// Force both arguments to absolute values.
   if ($R < 0) {$R = abs($R);}
   if ($D < 0) {$D = abs($D);}

// Handle computation for distance to the
// eye as measured from center of sphere.
   if ($radioButtonIndex == 0 && $errorFlag == FALSE)
{
   if ($R >= $D)
      {$errorFlag = TRUE;
       $out = "<B style='color:red;'>ERROR : &nbsp; The distance from the center must be greater than the radius.</B>\n";
       $H = $S = "";
      }
   else
      {
$H = "<span style='font-size:90%;'>Line-of-Sight Distance (<B>H</B>) to Horizon =</span> <CODE>" . SqRt($D*$D - $R*$R) . "</CODE>";

$S = "<span style='font-size:90%;'>Surface Distance (<B>S</B>) to Horizon =</span> <CODE>" . $R * (M_PI/2 - (aCos(SqRt($D*$D - $R*$R) / $D))) . "</CODE>";

$out = $H . "<BR>$S<BR><BR>The distance <code>(D)</code> to the eye is reckoned from the center of the sphere.";

}
}


// Handle computation for distance to the
// eye as measured from surface of sphere.
   if ($radioButtonIndex == 1 && $errorFlag == FALSE)
{
   if ($D <= 0 || $R < 0)
      {$errorFlag = TRUE;
       $H = "<B CLASS=\"TxRed\">Error : &nbsp; Radius and distance should both be greater than zero.</B>\n";
       $S = "";
      }
   else
      {
$H = "<span style='font-size:90%;'>Line-Of-Sight Distance (<B>H</B>) to Horizon =</span> <CODE>" . SqRt(($R + $D)*($R + $D) - $R*$R) . "</CODE>";

$S = "<span style='font-size:90%;'>Surface Distance (<B>S</B>) to Horizon =</span> <CODE>" . $R * (M_PI/2 - (aCos(SqRt(2 * $R * $D + $D*$D) / ($R + $D)))) . "</CODE>";

   $out = $H . "<BR>$S<BR><BR>Distance <code>(d)</code> to the eye is reckoned from the surface of the sphere.<br>This corresponds to the minimum radar distance to the nearest surface point.";
      }
}

// Generate start of HTML page

print <<< _HTML

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">

<HTML>

<HEAD>

<META HTTP-EQUIV="CONTENT-TYPE" CONTENT="TEXT/HTML; CHARSET=UTF-8">

<style type='text/css'>
BODY
{color:white; background-color:black;  font-family:Verdana; font-size:15px}

TABLE
{font-family:Verdana; font-size:12px; border: 1px solid black;}

LI
{text-align:justify;}

TD
{color:black; background-color:white;  border:1px solid black; line-height:125%; font-size:14px; padding:6px; text-align:center;}

DIV
{color:black; background-color:white;  font-family:Verdana; text-align:justify; padding:4px; font-size:14px;}


CODE
{font-family:monospace; font-size:16px; font-weight:bold;}


IMG
{border:1px solid #BBBBBB; box-shadow:2px 2px 3px #999999;}

INPUT[type="text"]::-ms-clear {width:0; height:0;}

INPUT[type="text"]
{color:black; background-color:white; font-size:18px; font-family:monospace; font-weight:bold; text-align:center; box-shadow:2px 2px 3px #999999; border:2px solid black;}

INPUT[type="text"]:focus
{background-color:white; font-family:monospace; font-size:18px; border:2px solid red; text-align:center; font-weight:bold; box-shadow:2px 2px 3px #666666;}

INPUT[type="submit"]
{font-weight:bold;}

INPUT[type="submit"]:hover
{box-shadow:2px 2px 5px #222222; font-weight:bold;}

INPUT[type="checkbox"]:checked
{box-shadow:2px 2px 3px #222222;}

HR {background-color:black; height:2px; border:0px;}

A:link,  A:visited {background-color:transparent; color:blue; font-family:Verdana; font-size:12px; font-weight:bold; text-decoration:none; line-height:150%; padding:2px;}
A:hover, A:active  {background-color:transparent; color:red;  font-family:Verdana; font-size:12px; font-weight:bold; text-decoration:none; line-height:150%; padding:2px;}

::selection      {background-color:yellow; color:black;}  /* Only affects IE9+ and Safari     */
::-moz-selection {background-color:yellow; color:black;}  /* Only affects FireFox and Mozilla */
</style>

<META NAME="robots" CONTENT="index,follow">

<TITLE>Distance To the Horizon of a Sphere</TITLE>

</HEAD>

<BODY>

<TABLE WIDTH="550" BGCOLOR="BLACK" CELLPADDING="4" CELLSPACING="1"><TR><TD>
<DIV style='font-size:85%;'>

<H3 ALIGN="center" style='color:white; background-color:#0000CC; border:1px solid black; padding:4px; font-size:125%;'><B>Distance From Eye to Horizon of a Sphere</B></H3>

This program computes the line-of-sight distance and the curved surface distance to the horizon of a sphere at any distance of the eye as reckoned from the surface or center of the sphere. &nbsp; The radius and distance can be in any convenient linear units. &nbsp;

<br><br>
The initial defaults radius is the mean lunar radius and the distance is 1/100th of the mean geocentric distance of the eye from the center of the moon, both in statute miles.
<BR><BR>
<FORM NAME="form1" ACTION="$_ACTION_FILE_NAME_" METHOD="post">

<TABLE width='100%' CELLPADDING="6" CELLSPACING="1">

<TR><TD style='color:black; background-color:white;' ALIGN="center"><B>Radius</B></TD><TD style='color:black; background-color:LightCyan; text-align:center;'><INPUT NAME="R" TYPE="text" SIZE="24" VALUE="$R" MAXLENGTH="24"> units</TD></TR>

<TR><TD style='color:white; background-color:black;' ALIGN="center"><B>Distance</B></TD><TD style='color:black; background-color:LightCyan; text-align:center;'><INPUT NAME="D" TYPE="text" SIZE="24" VALUE="$D" MAXLENGTH="24"> units</TD></TR>

<TR><TD style='color:black; background-color:white; font-size:80%;' ALIGN="center" COLSPAN="2"><B>Distance To Eye Reckoned From:&nbsp;&nbsp;&nbsp;&nbsp; </B>Center &nbsp;<INPUT NAME="DistOption" TYPE="radio" VALUE="0" $radioButton[0]>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Surface &nbsp;<INPUT NAME="DistOption" TYPE="radio" VALUE="1" $radioButton[1]></TD></TR>

<TR><TD COLSPAN="2" style='background-color:#DDDDDD; padding:8px;' ALIGN="center"><INPUT NAME="Compute_Button" TYPE="submit" VALUE="Compute"></TD></TR>

</TABLE>

</FORM>

$out

<BR><BR><BR>
<HR>
<DIV ALIGN="left"><IMG SRC="images/sphere_horizon_distance.png" ALT="">

<BR><BR>
<HR>
<DIV style='font-size:90%; text-align:justify;'><B>Where the Distance to the Eye Is Reckoned From the Center of the Sphere:</B>
<BR>
<BR>
Given the radius (<CODE>R</CODE>) of the sphere and the distance (<CODE>D</CODE>) of the eye from the center of the sphere, the general equation for the line-of-sight distance (<CODE>H</CODE>) to the sphere horizon viewed from that point is:

<br><br>
<div style='text-align:center;'><img src='images/H1.png'></div>
<br>

The horizon surface distance <code>(S)</code>, corresponding to <code>(H)</code>, but measured along the curved surface of the sphere directly below H and corresponding to the sailing distance is:

<br><br>
<div style='text-align:center;'><img src='images/S1.png'></div>
<br>

<div style='text-align:center;'>Where: <B>D</B> &gt; <B>R</B> and <B>R</B> &gt; <B>0</B> and the inverse angle is expressed in radians</div>
</div>

<br><br>
<hr>
<div style='text-align:center;'><B style='font-size:90%;'>Where the Distance to the Eye Is Reckoned From the Surface of the Sphere:</B></div>

<br>
<div style='font-size:90%;'>
Given the radius <CODE>(R)</CODE> of the sphere and the radar distance <CODE>(d)</CODE> <z>(</z>or height<z>)</z> of the eye above the surface of the sphere, the general equation for the line-of-sight distance <code>(H)</code> to the sphere horizon viewed from that point is:

<br><br>
<div style='text-align:center;'><img src='images/H2.png'></div>
<br>


The surface distance to the horizon point<code>(S)</code>, corresponding to line-of-sight distance <code>(H)</code>, but measured along the curved surface of the sphere, corresponding to the sailing distance is:
<br><br>
<div style='text-align:center;'><img src='images/S2.png'></div>
<br>

<div style='text-align:center;'>
Where: <B>R</B> &gt; <B>0</B> and <B>d</B> &gt; <B>0</B> and the inverse angle is expressed in radians</DIV>

<br><br>
<hr>

<DIV style='font-size:70%; text-align:center; color:gray;'><b>Jay Tanner - $cYear - $_PROGRAM_VERSION_</b></DIV>

</DIV>

</BODY>
</HTML>

_HTML;



?>


